@@ -3,7 +3,11 @@ pub use compound::Compound;
 pub use element::Element;
 pub use reactant::Reactant;
 pub use reaction::Reaction;
+pub use reaction_list::ReactionList;
 pub use sample::Sample;
+pub use theoretical_reaction::TheoreticalReaction;
+pub use theoretical_reaction::YieldUnits;
+pub use units::Units;
 pub use yield_reaction::YieldReaction;
 
 mod balanced_reaction;
@@ -11,5 +15,8 @@ mod compound;
 mod element;
 mod reactant;
 mod reaction;
+mod reaction_list;
 mod sample;
+mod theoretical_reaction;
+mod units;
 mod yield_reaction;
