@@ -38,4 +38,12 @@ impl Reactant {
                 acc
             });
     }
+
+    pub fn format(&self, explicit: bool) -> String {
+        if (self.molar_coefficient != 1 || explicit) {
+            format!("{}*{}", self.molar_coefficient, self.compound.formula)
+        } else {
+            format!("{}", self.compound.formula)
+        }
+    }
 }
